package com.example.facetter;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.PointF;
import android.graphics.RectF;
import android.media.FaceDetector;
import android.media.FaceDetector.Face;
import android.view.View;

public class FaceView extends View {

    private FaceDetector.Face[] mFaces; // 顔認識結果
    private Bitmap mIcon;               // アイコン画像

    public FaceView(Context context) {
        super(context);
    }

    public void setFaces(FaceDetector.Face[] faces) {
        mFaces = faces;
    }

    public void setIcon(Bitmap icon) {
        mIcon = icon;
    }

    @Override
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);

        // 顔認識結果がない場合は何もしない
        if (mFaces == null) return;

        for (int i = 0; i < mFaces.length; i++) {
            // 顔認識結果から矩形情報を作る
            Face face = mFaces[i];
            PointF point = new PointF(0, 0);
            face.getMidPoint(point);
            float eyesDistance = face.eyesDistance();
            RectF rect = new RectF();
            rect.left   = point.x - eyesDistance * 2;
            rect.top    = point.y - eyesDistance * 2;
            rect.right  = point.x + eyesDistance * 2;
            rect.bottom = point.y + eyesDistance * 2;
            // アイコン画像を描画する
            canvas.drawBitmap(mIcon, null, rect, null);
        }
    }
}
