package com.example.facetter;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import twitter4j.Twitter;
import twitter4j.TwitterException;
import twitter4j.TwitterFactory;
import twitter4j.User;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

public class IconListAdapter extends BaseAdapter {

    private Context mContext;
    private List<IconData> mIconDatas;

    public IconListAdapter(Context context) {
        mContext = context;
        String id = FacetterPreferenceActivity.getID(context);
        String pass = FacetterPreferenceActivity.getPassword(context);
        mIconDatas = createIconDatas(id, pass);
    }

    // リストアイテムの数を返します。
    public int getCount() {
        return mIconDatas.size();
    }

    // リストアイテムを返します。
    public Object getItem(int position) {
        return mIconDatas.get(position);
    }

    // リストアイテムのIDを返します。
    public long getItemId(int position) {
        return position;
    }

    // リストアイテムを表示するビューを返します。
    public View getView(int position, View convertView, ViewGroup parent) {
        return new IconDataView(mContext, mIconDatas.get(position));
    }

    // LinearLayoutを継承したビューを定義します。
    private class IconDataView extends LinearLayout {
        public IconDataView(Context context, IconData iconData) {
            super(context);

            // アイコン画像を表示するためのImageView
            ImageView imageView = new ImageView(mContext);
            imageView.setImageBitmap(iconData.icon);
            addView(imageView);

            // Twitterのユーザ名を表示するためのTextView
            TextView textView = new TextView(mContext);
            textView.setText(iconData.name);
            addView(textView);
        }
    }

    // 指定されたIDとパスワードでTwitter APIを利用して、IconDataのリストを生成します。
    private List<IconData> createIconDatas(String id, String pass) {
        List<IconData> iconDatas = new ArrayList<IconData>();

        TwitterFactory twitterFactory = new TwitterFactory();
        Twitter twitter = twitterFactory.getInstance(id, pass);
        try {
            // Friendsを取得
            List<User> friends = twitter.getFriendsStatuses();
            // サンプルのため20件を取得
            int max = 20;
            for (int i = 0; i < max; i++) {
                iconDatas.add(userToIconData(friends.get(i)));
            }
        } catch (TwitterException e) {
            Log.d(getClass().getName(), e.getMessage());
        }
        return iconDatas;
    }

    // twitter4j.UserからIconDataを生成します。
    private IconData userToIconData(User user) {
        IconData iconData = new IconData();
        iconData.icon = urlToBitmap(user.getProfileImageURL());
        iconData.name = user.getName();
        return iconData;
    }

    // URLからBitmapを生成します。
    private Bitmap urlToBitmap(URL url) {
        try {
            InputStream inputStream = url.openStream();
            return BitmapFactory.decodeStream(inputStream);
        } catch (IOException e) {
            Log.d(getClass().getName(), e.getMessage());
            return null;
        }
    }
}
