package com.example.facetter;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ImageView;

public class MainActivity extends Activity
    implements OnClickListener {

    private static final int ICON_LIST_ACTIVITY = 1;

    private Bitmap mIcon = null; // アイコン画像

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);

        Button button1 = (Button)findViewById(R.id.Button01);
        button1.setOnClickListener(this);

        Button button2 = (Button)findViewById(R.id.Button02);
        button2.setOnClickListener(this);

        Button button3 = (Button)findViewById(R.id.Button03);
        button3.setOnClickListener(this);

        // 起動時はデフォルトアイコン画像をロード
        mIcon = BitmapFactory.decodeResource(getResources(), R.drawable.default_icon);
        // アイコン画像を再描画
        drawIcon();
    }

    public void onClick(View v) {
        if (v.getId() == R.id.Button01) {
            // CameraActivityを呼び出す
            Intent intent = new Intent(this,
                                       CameraActivity.class);
            intent.putExtra("icon", mIcon);
            startActivity(intent);
        }

        if (v.getId() == R.id.Button02) {
            // IconListActivityを呼び出す
            Intent intent = new Intent(this, IconListActivity.class);
            startActivityForResult(intent, ICON_LIST_ACTIVITY);
        }

        if (v.getId() == R.id.Button03) {
            // 設定画面（FacetterPreferenceActivity）を呼び出す
            Intent intent = new Intent(this, FacetterPreferenceActivity.class);
            startActivity(intent);
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == ICON_LIST_ACTIVITY) {
            // アイコン画像を受け取る
            mIcon = (Bitmap)data.getExtras().getParcelable("icon");
            // アイコン画像を再描画
            drawIcon();
        }
    }

    // アイコン画像を再描画します。
    private void drawIcon() {
        ImageView imageView = (ImageView)findViewById(R.id.IconImageView);
        imageView.setImageBitmap(mIcon);
        imageView.invalidate();
    }
}